This readme file is going to define some dependencies of this library before using it
This package implements the module for Outlier Removal. Make sure your data does not contain any NULL values in it. Provide the source and destination csv files while executing the code on your local machine.
Install all the dependencies.